@@ -40,7 +40,7 @@ class PaddlePredict(object):
 
     def predict(self, input_list):
         if self.use_paddle_inference:
-            for i in range(input_list):
+            for i in range(len(input_list)):
                 self.input_handles[i].copy_from_cpu(input_list[i])
 
             self.predictor.run()
